@@ -4,9 +4,8 @@
  * Author: André Borrmann
  * License: Apache License 2.0
  **************************************************************************************************/
-#![doc(html_root_url = "https://docs.rs/ruspiro-timer/0.5.1")]
+#![doc(html_root_url = "https://docs.rs/ruspiro-timer/0.6.0")]
 #![cfg_attr(not(any(test, doctest)), no_std)]
-#![feature(llvm_asm)]
 //! # Timer functions
 //!
 //! This crate provides simple timing functions to pause the actual processing for a specific amount of time. The core
@@ -21,6 +20,9 @@
 //! `ruspiro_pi3` | active to use the proper timer MMIO base memory address for Raspberry Pi 3 when accessing the system timer peripheral
 //!
 
+#[cfg(not(any(feature = "pi3", feature = "pi4_low", feature = "pi4_high")))]
+compile_error!("Either feature \"pi3\", \"pi4_low\" or \"pi4_high\" must be enabled for this crate");
+
 extern crate alloc;
 
 mod interface;
